==> cxf-testutils-2.0.6.3-fuse-sources.jar: org/apache/type_test/xml/TestExtendsSimpleType.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ExtendsSimpleType;


/**
 * <p>Java class for testExtendsSimpleType element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testExtendsSimpleType">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}ExtendsSimpleType"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}ExtendsSimpleType"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testExtendsSimpleType")
public class TestExtendsSimpleType {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected ExtendsSimpleType x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected ExtendsSimpleType y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public ExtendsSimpleType getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public void setX(ExtendsSimpleType value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public ExtendsSimpleType getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public void setY(ExtendsSimpleType value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestExtendsSimpleType.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ExtendsSimpleType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}ExtendsSimpleType"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}ExtendsSimpleType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testExtendsSimpleType")
public class TestExtendsSimpleType {

    @XmlElement(required = true)
    protected ExtendsSimpleType x;
    @XmlElement(required = true)
    protected ExtendsSimpleType y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public ExtendsSimpleType getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public void setX(ExtendsSimpleType value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public ExtendsSimpleType getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtendsSimpleType }
     *     
     */
    public void setY(ExtendsSimpleType value) {
        this.y = value;
    }

}
